@@ -97,6 +97,7 @@ import aws_cdk.aws_apigateway
 import aws_cdk.aws_cognito
 import aws_cdk.aws_dynamodb
 import aws_cdk.aws_ec2
+import aws_cdk.aws_elasticloadbalancingv2
 import aws_cdk.aws_events
 import aws_cdk.aws_glue
 import aws_cdk.aws_iam
@@ -929,6 +930,7 @@ class BuildQueueProps:
     name_mapping={
         "bucket_props": "bucketProps",
         "logging_bucket_props": "loggingBucketProps",
+        "log_s3_access_logs": "logS3AccessLogs",
     },
 )
 class BuildS3BucketProps:
@@ -937,10 +939,12 @@ class BuildS3BucketProps:
         *,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param logging_bucket_props: User provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
+        :param log_s3_access_logs: Whether to turn on Access Logs for S3. Uses an S3 bucket with associated storage costs. Enabling Access Logging is a best practice. Default: - true
         '''
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
@@ -951,6 +955,8 @@ class BuildS3BucketProps:
             self._values["bucket_props"] = bucket_props
         if logging_bucket_props is not None:
             self._values["logging_bucket_props"] = logging_bucket_props
+        if log_s3_access_logs is not None:
+            self._values["log_s3_access_logs"] = log_s3_access_logs
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
@@ -970,6 +976,18 @@ class BuildS3BucketProps:
         result = self._values.get("logging_bucket_props")
         return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
 
+    @builtins.property
+    def log_s3_access_logs(self) -> typing.Optional[builtins.bool]:
+        '''Whether to turn on Access Logs for S3.
+
+        Uses an S3 bucket with associated storage costs.
+        Enabling Access Logging is a best practice.
+
+        :default: - true
+        '''
+        result = self._values.get("log_s3_access_logs")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1818,6 +1836,7 @@ class SinkStoreType(enum.Enum):
     jsii_type="@aws-solutions-constructs/core.VerifiedProps",
     jsii_struct_bases=[],
     name_mapping={
+        "alb_logging_bucket_props": "albLoggingBucketProps",
         "bucket_props": "bucketProps",
         "dead_letter_queue_props": "deadLetterQueueProps",
         "deploy_dead_letter_queue": "deployDeadLetterQueue",
@@ -1830,6 +1849,8 @@ class SinkStoreType(enum.Enum):
         "existing_bucket_obj": "existingBucketObj",
         "existing_glue_job": "existingGlueJob",
         "existing_lambda_obj": "existingLambdaObj",
+        "existing_load_balancer_obj": "existingLoadBalancerObj",
+        "existing_logging_bucket_obj": "existingLoggingBucketObj",
         "existing_media_store_container_obj": "existingMediaStoreContainerObj",
         "existing_queue_obj": "existingQueueObj",
         "existing_sagemaker_endpoint_obj": "existingSagemakerEndpointObj",
@@ -1842,6 +1863,10 @@ class SinkStoreType(enum.Enum):
         "glue_job_props": "glueJobProps",
         "kinesis_stream_props": "kinesisStreamProps",
         "lambda_function_props": "lambdaFunctionProps",
+        "load_balancer_props": "loadBalancerProps",
+        "log_alb_access_logs": "logAlbAccessLogs",
+        "logging_bucket_props": "loggingBucketProps",
+        "log_s3_access_logs": "logS3AccessLogs",
         "media_store_container_props": "mediaStoreContainerProps",
         "queue_props": "queueProps",
         "secret_props": "secretProps",
@@ -1853,6 +1878,7 @@ class VerifiedProps:
     def __init__(
         self,
         *,
+        alb_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
@@ -1865,6 +1891,8 @@ class VerifiedProps:
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
         existing_glue_job: typing.Optional[aws_cdk.aws_glue.CfnJob] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
+        existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         existing_sagemaker_endpoint_obj: typing.Optional[aws_cdk.aws_sagemaker.CfnEndpoint] = None,
@@ -1877,6 +1905,10 @@ class VerifiedProps:
         glue_job_props: typing.Optional[aws_cdk.aws_glue.CfnJobProps] = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        load_balancer_props: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancerProps] = None,
+        log_alb_access_logs: typing.Optional[builtins.bool] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        log_s3_access_logs: typing.Optional[builtins.bool] = None,
         media_store_container_props: typing.Optional[aws_cdk.aws_mediastore.CfnContainerProps] = None,
         queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         secret_props: typing.Optional[aws_cdk.aws_secretsmanager.SecretProps] = None,
@@ -1884,6 +1916,7 @@ class VerifiedProps:
         vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
+        :param alb_logging_bucket_props: -
         :param bucket_props: -
         :param dead_letter_queue_props: -
         :param deploy_dead_letter_queue: -
@@ -1896,6 +1929,8 @@ class VerifiedProps:
         :param existing_bucket_obj: -
         :param existing_glue_job: -
         :param existing_lambda_obj: -
+        :param existing_load_balancer_obj: -
+        :param existing_logging_bucket_obj: -
         :param existing_media_store_container_obj: -
         :param existing_queue_obj: -
         :param existing_sagemaker_endpoint_obj: -
@@ -1908,12 +1943,18 @@ class VerifiedProps:
         :param glue_job_props: -
         :param kinesis_stream_props: -
         :param lambda_function_props: -
+        :param load_balancer_props: -
+        :param log_alb_access_logs: -
+        :param logging_bucket_props: -
+        :param log_s3_access_logs: -
         :param media_store_container_props: -
         :param queue_props: -
         :param secret_props: -
         :param topic_props: -
         :param vpc_props: -
         '''
+        if isinstance(alb_logging_bucket_props, dict):
+            alb_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**alb_logging_bucket_props)
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(dead_letter_queue_props, dict):
@@ -1930,6 +1971,10 @@ class VerifiedProps:
             kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if isinstance(load_balancer_props, dict):
+            load_balancer_props = aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancerProps(**load_balancer_props)
+        if isinstance(logging_bucket_props, dict):
+            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(media_store_container_props, dict):
             media_store_container_props = aws_cdk.aws_mediastore.CfnContainerProps(**media_store_container_props)
         if isinstance(queue_props, dict):
@@ -1941,6 +1986,8 @@ class VerifiedProps:
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         self._values: typing.Dict[str, typing.Any] = {}
+        if alb_logging_bucket_props is not None:
+            self._values["alb_logging_bucket_props"] = alb_logging_bucket_props
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
         if dead_letter_queue_props is not None:
@@ -1965,6 +2012,10 @@ class VerifiedProps:
             self._values["existing_glue_job"] = existing_glue_job
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
+        if existing_load_balancer_obj is not None:
+            self._values["existing_load_balancer_obj"] = existing_load_balancer_obj
+        if existing_logging_bucket_obj is not None:
+            self._values["existing_logging_bucket_obj"] = existing_logging_bucket_obj
         if existing_media_store_container_obj is not None:
             self._values["existing_media_store_container_obj"] = existing_media_store_container_obj
         if existing_queue_obj is not None:
@@ -1989,6 +2040,14 @@ class VerifiedProps:
             self._values["kinesis_stream_props"] = kinesis_stream_props
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
+        if load_balancer_props is not None:
+            self._values["load_balancer_props"] = load_balancer_props
+        if log_alb_access_logs is not None:
+            self._values["log_alb_access_logs"] = log_alb_access_logs
+        if logging_bucket_props is not None:
+            self._values["logging_bucket_props"] = logging_bucket_props
+        if log_s3_access_logs is not None:
+            self._values["log_s3_access_logs"] = log_s3_access_logs
         if media_store_container_props is not None:
             self._values["media_store_container_props"] = media_store_container_props
         if queue_props is not None:
@@ -2000,6 +2059,11 @@ class VerifiedProps:
         if vpc_props is not None:
             self._values["vpc_props"] = vpc_props
 
+    @builtins.property
+    def alb_logging_bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+        result = self._values.get("alb_logging_bucket_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
         result = self._values.get("bucket_props")
@@ -2060,6 +2124,18 @@ class VerifiedProps:
         result = self._values.get("existing_lambda_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
+    @builtins.property
+    def existing_load_balancer_obj(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer]:
+        result = self._values.get("existing_load_balancer_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer], result)
+
+    @builtins.property
+    def existing_logging_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
+        result = self._values.get("existing_logging_bucket_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
+
     @builtins.property
     def existing_media_store_container_obj(
         self,
@@ -2126,6 +2202,28 @@ class VerifiedProps:
         result = self._values.get("lambda_function_props")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
+    @builtins.property
+    def load_balancer_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancerProps]:
+        result = self._values.get("load_balancer_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancerProps], result)
+
+    @builtins.property
+    def log_alb_access_logs(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("log_alb_access_logs")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def logging_bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+        result = self._values.get("logging_bucket_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+
+    @builtins.property
+    def log_s3_access_logs(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("log_s3_access_logs")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def media_store_container_props(
         self,
